# Standard: Class method scope ordering

Methods within a class should always be defined in order: public, protected, private.

## Reasoning

When using a class, the most important methods are the ones it exposes to the outside world - public. Methods available to sub-classes may also be important - protected. Private methods are scoped and are an implementation detail for that particular class, so only relevant if refactoring.

## Good

```php
public function two()
{
}

protected function four()
{
}

private function six()
{
}
```

## Bad

```php
protected function one()
{
}

private function two()
{
}

public function four()
{
}
```