# Standard: Class property ordering

Class properties should always be defined before any methods.

## Reasoning

Class properties shouldn't be interpolated with methods - it makes them hard to find when working with the class or trying to refactor it. Putting them in one place ensures that they are easier to reason about.

## Good

```php
class MyClass
{
    public $one = '1';
    protected $two = '2';
    private $three = '3';
    
    public function one()
    {
    }
}
```

## Bad

```php
class MyClass
{
    public function one()
    {
    }
    
    private $two = '2';
    
    protected function three()
    {
    }
    
    public $four = '4';
    protected $five = '5';
}
```